==> aws-cdk-lib-2.51.1-sources.jar: software/amazon/awscdk/services/elasticsearch/CapacityConfig.java <==
package software.amazon.awscdk.services.elasticsearch;

/**
 * (deprecated) Configures the capacity of the cluster such as the instance type and the number of instances.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Domain domain = Domain.Builder.create(this, "Domain")
 *         .version(ElasticsearchVersion.V7_10)
 *         .capacity(CapacityConfig.builder()
 *                 .masterNodes(2)
 *                 .warmNodes(2)
 *                 .warmInstanceType("ultrawarm1.medium.elasticsearch")
 *                 .build())
 *         .build();
 * </pre></blockquote>
 * <p>
 * @deprecated use opensearchservice module instead
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-11-18T21:59:11.679Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_elasticsearch.CapacityConfig")
@software.amazon.jsii.Jsii.Proxy(CapacityConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface CapacityConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * (deprecated) The instance type for your data nodes, such as `m3.medium.elasticsearch`. For valid values, see [Supported Instance Types](https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-supported-instance-types.html) in the Amazon Elasticsearch Service Developer Guide.
     * <p>
     * Default: - r5.large.elasticsearch
     * <p>
     * @deprecated use opensearchservice module instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getDataNodeInstanceType() {
        return null;
    }

    /**
     * (deprecated) The number of data nodes (instances) to use in the Amazon ES domain.
     * <p>
     * Default: - 1
     * <p>
     * @deprecated use opensearchservice module instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.Number getDataNodes() {
        return null;
    }

    /**
     * (deprecated) The hardware configuration of the computer that hosts the dedicated master node, such as `m3.medium.elasticsearch`. For valid values, see [Supported Instance Types] (https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-supported-instance-types.html) in the Amazon Elasticsearch Service Developer Guide.
     * <p>
     * Default: - r5.large.elasticsearch
     * <p>
     * @deprecated use opensearchservice module instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getMasterNodeInstanceType() {
        return null;
    }

    /**
     * (deprecated) The number of instances to use for the master node.
     * <p>
     * Default: - no dedicated master nodes
     * <p>
     * @deprecated use opensearchservice module instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.Number getMasterNodes() {
        return null;
    }

    /**
     * (deprecated) The instance type for your UltraWarm node, such as `ultrawarm1.medium.elasticsearch`. For valid values, see [UltraWarm Storage Limits] (https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-limits.html#limits-ultrawarm) in the Amazon Elasticsearch Service Developer Guide.
     * <p>
     * Default: - ultrawarm1.medium.elasticsearch
     * <p>
     * @deprecated use opensearchservice module instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getWarmInstanceType() {
        return null;
    }

    /**
     * (deprecated) The number of UltraWarm nodes (instances) to use in the Amazon ES domain.
     * <p>
     * Default: - no UltraWarm nodes
     * <p>
     * @deprecated use opensearchservice module instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.Number getWarmNodes() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CapacityConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CapacityConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<CapacityConfig> {
        java.lang.String dataNodeInstanceType;
        java.lang.Number dataNodes;
        java.lang.String masterNodeInstanceType;
        java.lang.Number masterNodes;
        java.lang.String warmInstanceType;
        java.lang.Number warmNodes;

        /**
         * Sets the value of {@link CapacityConfig#getDataNodeInstanceType}
         * @param dataNodeInstanceType The instance type for your data nodes, such as `m3.medium.elasticsearch`. For valid values, see [Supported Instance Types](https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-supported-instance-types.html) in the Amazon Elasticsearch Service Developer Guide.
         * @return {@code this}
         * @deprecated use opensearchservice module instead
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder dataNodeInstanceType(java.lang.String dataNodeInstanceType) {
            this.dataNodeInstanceType = dataNodeInstanceType;
            return this;
        }

        /**
         * Sets the value of {@link CapacityConfig#getDataNodes}
         * @param dataNodes The number of data nodes (instances) to use in the Amazon ES domain.
         * @return {@code this}
         * @deprecated use opensearchservice module instead
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder dataNodes(java.lang.Number dataNodes) {
            this.dataNodes = dataNodes;
            return this;
        }

        /**
         * Sets the value of {@link CapacityConfig#getMasterNodeInstanceType}
         * @param masterNodeInstanceType The hardware configuration of the computer that hosts the dedicated master node, such as `m3.medium.elasticsearch`. For valid values, see [Supported Instance Types] (https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-supported-instance-types.html) in the Amazon Elasticsearch Service Developer Guide.
         * @return {@code this}
         * @deprecated use opensearchservice module instead
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder masterNodeInstanceType(java.lang.String masterNodeInstanceType) {
            this.masterNodeInstanceType = masterNodeInstanceType;
            return this;
        }

        /**
         * Sets the value of {@link CapacityConfig#getMasterNodes}
         * @param masterNodes The number of instances to use for the master node.
         * @return {@code this}
         * @deprecated use opensearchservice module instead
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder masterNodes(java.lang.Number masterNodes) {
            this.masterNodes = masterNodes;
            return this;
        }

        /**
         * Sets the value of {@link CapacityConfig#getWarmInstanceType}
         * @param warmInstanceType The instance type for your UltraWarm node, such as `ultrawarm1.medium.elasticsearch`. For valid values, see [UltraWarm Storage Limits] (https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-limits.html#limits-ultrawarm) in the Amazon Elasticsearch Service Developer Guide.
         * @return {@code this}
         * @deprecated use opensearchservice module instead
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder warmInstanceType(java.lang.String warmInstanceType) {
            this.warmInstanceType = warmInstanceType;
            return this;
        }

        /**
         * Sets the value of {@link CapacityConfig#getWarmNodes}
         * @param warmNodes The number of UltraWarm nodes (instances) to use in the Amazon ES domain.
         * @return {@code this}
         * @deprecated use opensearchservice module instead
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder warmNodes(java.lang.Number warmNodes) {
            this.warmNodes = warmNodes;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CapacityConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public CapacityConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CapacityConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CapacityConfig {
        private final java.lang.String dataNodeInstanceType;
        private final java.lang.Number dataNodes;
        private final java.lang.String masterNodeInstanceType;
        private final java.lang.Number masterNodes;
        private final java.lang.String warmInstanceType;
        private final java.lang.Number warmNodes;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.dataNodeInstanceType = software.amazon.jsii.Kernel.get(this, "dataNodeInstanceType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.dataNodes = software.amazon.jsii.Kernel.get(this, "dataNodes", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.masterNodeInstanceType = software.amazon.jsii.Kernel.get(this, "masterNodeInstanceType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.masterNodes = software.amazon.jsii.Kernel.get(this, "masterNodes", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.warmInstanceType = software.amazon.jsii.Kernel.get(this, "warmInstanceType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.warmNodes = software.amazon.jsii.Kernel.get(this, "warmNodes", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.dataNodeInstanceType = builder.dataNodeInstanceType;
            this.dataNodes = builder.dataNodes;
            this.masterNodeInstanceType = builder.masterNodeInstanceType;
            this.masterNodes = builder.masterNodes;
            this.warmInstanceType = builder.warmInstanceType;
            this.warmNodes = builder.warmNodes;
        }

        @Override
        public final java.lang.String getDataNodeInstanceType() {
            return this.dataNodeInstanceType;
        }

        @Override
        public final java.lang.Number getDataNodes() {
            return this.dataNodes;
        }

        @Override
        public final java.lang.String getMasterNodeInstanceType() {
            return this.masterNodeInstanceType;
        }

        @Override
        public final java.lang.Number getMasterNodes() {
            return this.masterNodes;
        }

        @Override
        public final java.lang.String getWarmInstanceType() {
            return this.warmInstanceType;
        }

        @Override
        public final java.lang.Number getWarmNodes() {
            return this.warmNodes;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDataNodeInstanceType() != null) {
                data.set("dataNodeInstanceType", om.valueToTree(this.getDataNodeInstanceType()));
            }
            if (this.getDataNodes() != null) {
                data.set("dataNodes", om.valueToTree(this.getDataNodes()));
            }
            if (this.getMasterNodeInstanceType() != null) {
                data.set("masterNodeInstanceType", om.valueToTree(this.getMasterNodeInstanceType()));
            }
            if (this.getMasterNodes() != null) {
                data.set("masterNodes", om.valueToTree(this.getMasterNodes()));
            }
            if (this.getWarmInstanceType() != null) {
                data.set("warmInstanceType", om.valueToTree(this.getWarmInstanceType()));
            }
            if (this.getWarmNodes() != null) {
                data.set("warmNodes", om.valueToTree(this.getWarmNodes()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_elasticsearch.CapacityConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CapacityConfig.Jsii$Proxy that = (CapacityConfig.Jsii$Proxy) o;

            if (this.dataNodeInstanceType != null ? !this.dataNodeInstanceType.equals(that.dataNodeInstanceType) : that.dataNodeInstanceType != null) return false;
            if (this.dataNodes != null ? !this.dataNodes.equals(that.dataNodes) : that.dataNodes != null) return false;
            if (this.masterNodeInstanceType != null ? !this.masterNodeInstanceType.equals(that.masterNodeInstanceType) : that.masterNodeInstanceType != null) return false;
            if (this.masterNodes != null ? !this.masterNodes.equals(that.masterNodes) : that.masterNodes != null) return false;
            if (this.warmInstanceType != null ? !this.warmInstanceType.equals(that.warmInstanceType) : that.warmInstanceType != null) return false;
            return this.warmNodes != null ? this.warmNodes.equals(that.warmNodes) : that.warmNodes == null;
        }

        @Override
        public final int hashCode() {
            int result = this.dataNodeInstanceType != null ? this.dataNodeInstanceType.hashCode() : 0;
            result = 31 * result + (this.dataNodes != null ? this.dataNodes.hashCode() : 0);
            result = 31 * result + (this.masterNodeInstanceType != null ? this.masterNodeInstanceType.hashCode() : 0);
            result = 31 * result + (this.masterNodes != null ? this.masterNodes.hashCode() : 0);
            result = 31 * result + (this.warmInstanceType != null ? this.warmInstanceType.hashCode() : 0);
            result = 31 * result + (this.warmNodes != null ? this.warmNodes.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.130.0-sources.jar: software/amazon/awscdk/services/elasticsearch/CapacityConfig.java <==
package software.amazon.awscdk.services.elasticsearch;

/**
 * (deprecated) Configures the capacity of the cluster such as the instance type and the number of instances.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Domain domain = Domain.Builder.create(this, "Domain")
 *         .version(ElasticsearchVersion.V7_10)
 *         .capacity(CapacityConfig.builder()
 *                 .masterNodes(2)
 *                 .warmNodes(2)
 *                 .warmInstanceType("ultrawarm1.medium.elasticsearch")
 *                 .build())
 *         .build();
 * </pre></blockquote>
 * <p>
 * @deprecated use opensearchservice module instead
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-02-23T02:06:32.529Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_elasticsearch.CapacityConfig")
@software.amazon.jsii.Jsii.Proxy(CapacityConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface CapacityConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * (deprecated) The instance type for your data nodes, such as <code>m3.medium.elasticsearch</code>. For valid values, see <a href="https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-supported-instance-types.html">Supported Instance Types</a> in the Amazon Elasticsearch Service Developer Guide.
     * <p>
     * Default: - r5.large.elasticsearch
     * <p>
     * @deprecated use opensearchservice module instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getDataNodeInstanceType() {
        return null;
    }

    /**
     * (deprecated) The number of data nodes (instances) to use in the Amazon ES domain.
     * <p>
     * Default: - 1
     * <p>
     * @deprecated use opensearchservice module instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.Number getDataNodes() {
        return null;
    }

    /**
     * (deprecated) The hardware configuration of the computer that hosts the dedicated master node, such as <code>m3.medium.elasticsearch</code>. For valid values, see [Supported Instance Types] (https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-supported-instance-types.html) in the Amazon Elasticsearch Service Developer Guide.
     * <p>
     * Default: - r5.large.elasticsearch
     * <p>
     * @deprecated use opensearchservice module instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getMasterNodeInstanceType() {
        return null;
    }

    /**
     * (deprecated) The number of instances to use for the master node.
     * <p>
     * Default: - no dedicated master nodes
     * <p>
     * @deprecated use opensearchservice module instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.Number getMasterNodes() {
        return null;
    }

    /**
     * (deprecated) The instance type for your UltraWarm node, such as <code>ultrawarm1.medium.elasticsearch</code>. For valid values, see [UltraWarm Storage Limits] (https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-limits.html#limits-ultrawarm) in the Amazon Elasticsearch Service Developer Guide.
     * <p>
     * Default: - ultrawarm1.medium.elasticsearch
     * <p>
     * @deprecated use opensearchservice module instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getWarmInstanceType() {
        return null;
    }

    /**
     * (deprecated) The number of UltraWarm nodes (instances) to use in the Amazon ES domain.
     * <p>
     * Default: - no UltraWarm nodes
     * <p>
     * @deprecated use opensearchservice module instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.Number getWarmNodes() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CapacityConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CapacityConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<CapacityConfig> {
        java.lang.String dataNodeInstanceType;
        java.lang.Number dataNodes;
        java.lang.String masterNodeInstanceType;
        java.lang.Number masterNodes;
        java.lang.String warmInstanceType;
        java.lang.Number warmNodes;

        /**
         * Sets the value of {@link CapacityConfig#getDataNodeInstanceType}
         * @param dataNodeInstanceType The instance type for your data nodes, such as <code>m3.medium.elasticsearch</code>. For valid values, see <a href="https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-supported-instance-types.html">Supported Instance Types</a> in the Amazon Elasticsearch Service Developer Guide.
         * @return {@code this}
         * @deprecated use opensearchservice module instead
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder dataNodeInstanceType(java.lang.String dataNodeInstanceType) {
            this.dataNodeInstanceType = dataNodeInstanceType;
            return this;
        }

        /**
         * Sets the value of {@link CapacityConfig#getDataNodes}
         * @param dataNodes The number of data nodes (instances) to use in the Amazon ES domain.
         * @return {@code this}
         * @deprecated use opensearchservice module instead
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder dataNodes(java.lang.Number dataNodes) {
            this.dataNodes = dataNodes;
            return this;
        }

        /**
         * Sets the value of {@link CapacityConfig#getMasterNodeInstanceType}
         * @param masterNodeInstanceType The hardware configuration of the computer that hosts the dedicated master node, such as <code>m3.medium.elasticsearch</code>. For valid values, see [Supported Instance Types] (https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-supported-instance-types.html) in the Amazon Elasticsearch Service Developer Guide.
         * @return {@code this}
         * @deprecated use opensearchservice module instead
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder masterNodeInstanceType(java.lang.String masterNodeInstanceType) {
            this.masterNodeInstanceType = masterNodeInstanceType;
            return this;
        }

        /**
         * Sets the value of {@link CapacityConfig#getMasterNodes}
         * @param masterNodes The number of instances to use for the master node.
         * @return {@code this}
         * @deprecated use opensearchservice module instead
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder masterNodes(java.lang.Number masterNodes) {
            this.masterNodes = masterNodes;
            return this;
        }

        /**
         * Sets the value of {@link CapacityConfig#getWarmInstanceType}
         * @param warmInstanceType The instance type for your UltraWarm node, such as <code>ultrawarm1.medium.elasticsearch</code>. For valid values, see [UltraWarm Storage Limits] (https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/aes-limits.html#limits-ultrawarm) in the Amazon Elasticsearch Service Developer Guide.
         * @return {@code this}
         * @deprecated use opensearchservice module instead
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder warmInstanceType(java.lang.String warmInstanceType) {
            this.warmInstanceType = warmInstanceType;
            return this;
        }

        /**
         * Sets the value of {@link CapacityConfig#getWarmNodes}
         * @param warmNodes The number of UltraWarm nodes (instances) to use in the Amazon ES domain.
         * @return {@code this}
         * @deprecated use opensearchservice module instead
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder warmNodes(java.lang.Number warmNodes) {
            this.warmNodes = warmNodes;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CapacityConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public CapacityConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CapacityConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CapacityConfig {
        private final java.lang.String dataNodeInstanceType;
        private final java.lang.Number dataNodes;
        private final java.lang.String masterNodeInstanceType;
        private final java.lang.Number masterNodes;
        private final java.lang.String warmInstanceType;
        private final java.lang.Number warmNodes;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.dataNodeInstanceType = software.amazon.jsii.Kernel.get(this, "dataNodeInstanceType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.dataNodes = software.amazon.jsii.Kernel.get(this, "dataNodes", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.masterNodeInstanceType = software.amazon.jsii.Kernel.get(this, "masterNodeInstanceType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.masterNodes = software.amazon.jsii.Kernel.get(this, "masterNodes", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.warmInstanceType = software.amazon.jsii.Kernel.get(this, "warmInstanceType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.warmNodes = software.amazon.jsii.Kernel.get(this, "warmNodes", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.dataNodeInstanceType = builder.dataNodeInstanceType;
            this.dataNodes = builder.dataNodes;
            this.masterNodeInstanceType = builder.masterNodeInstanceType;
            this.masterNodes = builder.masterNodes;
            this.warmInstanceType = builder.warmInstanceType;
            this.warmNodes = builder.warmNodes;
        }

        @Override
        public final java.lang.String getDataNodeInstanceType() {
            return this.dataNodeInstanceType;
        }

        @Override
        public final java.lang.Number getDataNodes() {
            return this.dataNodes;
        }

        @Override
        public final java.lang.String getMasterNodeInstanceType() {
            return this.masterNodeInstanceType;
        }

        @Override
        public final java.lang.Number getMasterNodes() {
            return this.masterNodes;
        }

        @Override
        public final java.lang.String getWarmInstanceType() {
            return this.warmInstanceType;
        }

        @Override
        public final java.lang.Number getWarmNodes() {
            return this.warmNodes;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDataNodeInstanceType() != null) {
                data.set("dataNodeInstanceType", om.valueToTree(this.getDataNodeInstanceType()));
            }
            if (this.getDataNodes() != null) {
                data.set("dataNodes", om.valueToTree(this.getDataNodes()));
            }
            if (this.getMasterNodeInstanceType() != null) {
                data.set("masterNodeInstanceType", om.valueToTree(this.getMasterNodeInstanceType()));
            }
            if (this.getMasterNodes() != null) {
                data.set("masterNodes", om.valueToTree(this.getMasterNodes()));
            }
            if (this.getWarmInstanceType() != null) {
                data.set("warmInstanceType", om.valueToTree(this.getWarmInstanceType()));
            }
            if (this.getWarmNodes() != null) {
                data.set("warmNodes", om.valueToTree(this.getWarmNodes()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_elasticsearch.CapacityConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CapacityConfig.Jsii$Proxy that = (CapacityConfig.Jsii$Proxy) o;

            if (this.dataNodeInstanceType != null ? !this.dataNodeInstanceType.equals(that.dataNodeInstanceType) : that.dataNodeInstanceType != null) return false;
            if (this.dataNodes != null ? !this.dataNodes.equals(that.dataNodes) : that.dataNodes != null) return false;
            if (this.masterNodeInstanceType != null ? !this.masterNodeInstanceType.equals(that.masterNodeInstanceType) : that.masterNodeInstanceType != null) return false;
            if (this.masterNodes != null ? !this.masterNodes.equals(that.masterNodes) : that.masterNodes != null) return false;
            if (this.warmInstanceType != null ? !this.warmInstanceType.equals(that.warmInstanceType) : that.warmInstanceType != null) return false;
            return this.warmNodes != null ? this.warmNodes.equals(that.warmNodes) : that.warmNodes == null;
        }

        @Override
        public final int hashCode() {
            int result = this.dataNodeInstanceType != null ? this.dataNodeInstanceType.hashCode() : 0;
            result = 31 * result + (this.dataNodes != null ? this.dataNodes.hashCode() : 0);
            result = 31 * result + (this.masterNodeInstanceType != null ? this.masterNodeInstanceType.hashCode() : 0);
            result = 31 * result + (this.masterNodes != null ? this.masterNodes.hashCode() : 0);
            result = 31 * result + (this.warmInstanceType != null ? this.warmInstanceType.hashCode() : 0);
            result = 31 * result + (this.warmNodes != null ? this.warmNodes.hashCode() : 0);
            return result;
        }
    }
}
